.. panoramisk documentation master file, created by
   sphinx-quickstart on Thu Jan  9 12:06:32 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

=============
Installation
=============

Install, upgrade and uninstall panoramisk with these commands:

.. code-block:: sh

    $ pip install panoramisk
    $ pip install --upgrade panoramisk
    $ pip uninstall panoramisk


========================
Detailed Documentation
========================

.. toctree::
   :maxdepth: 1

   manager.rst
   fast_agi.rst
   testing.rst


===================================
Who use Panoramisk on production ?
===================================

For now, mainly `Eyepea
<http://www.eyepea.eu/>`_ and `ALLOcloud
<http://www.allocloud.com/>`_.

You shouldn't know theses companies, however, Eyepea is a provider of several famous European companies and governments organizations.
You can check their references on their website:

* http://www.eyepea.eu/customers
* http://www.eyepea.eu/company/news

Moreover, ALLOcloud is a cloud solution for SMEs, it handles several millions of calls by month.

If you also use Panoramisk on production, don't hesitate to open a pull request to add your company's name with some details.

=======
CHANGES
=======

.. include:: ../CHANGES.rst

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

